@@ -69,7 +69,8 @@ class AdaptedTest(nose.case.Test):
         self.test.id = self._make_testcase_id_func()
         self.test.__str__ = self._make_testcase_str_func()
         self.test.__repr__ = self._make_testcase_repr_func()
-        self.test.shortDescription = self._make_testcase_short_desc_func()
+        self.test.short_description = self._make_testcase_short_desc_func()
+        self.test.shortDescription = self.test.short_description
 
     def _make_testcase_id_func(self):
         orig_testcase_id = self.test.id()
@@ -93,7 +94,7 @@ class AdaptedTest(nose.case.Test):
     def _make_testcase_short_desc_func(self):
         orig_testcase_desc_func = getattr(
             self.test, 'shortDescription',
-            self._make_testcase_str_func())
+            lambda: None)
         orig_testcase_desc = orig_testcase_desc_func()
         scenario_id = self.test.scenario_id
         if orig_testcase_desc is not None:
@@ -123,7 +124,7 @@ class AdaptedTestSuite(base_suite_class):
                 case, as defined for ``AdaptedTest``.
 
             """
-        self.scenarios = scenarios
+        self.scenario_applier = TestScenarioApplier(scenarios)
         super(AdaptedTestSuite, self).__init__(tests, *args, **kwargs)
 
     def add_tests(self, collection):
@@ -133,17 +134,15 @@ class AdaptedTestSuite(base_suite_class):
                 An iterable of test cases to be adapted and added.
             :return: None
 
-            Each specified test case will be adapted by a
-            ``TestScenarioApplier`` using the ``scenarios`` used to
-            create this suite. The result will be that each test case
-            is adapted and added multiple times, once for each
-            scenario.
+            Each specified test case will be adapted by the
+            ``scenario_applier`` of this suite. The result is that
+            each test case is adapted and added multiple times, once
+            for each scenario.
 
             """
-        applier = TestScenarioApplier(self.scenarios)
-        for testcase in collection:
-            for adapted_testcase in applier.adapt(testcase):
-                super(AdaptedTestSuite, self).addTest(adapted_testcase)
+        for base_testcase in collection:
+            for testcase in self.scenario_applier.adapt(base_testcase):
+                super(AdaptedTestSuite, self).addTest(testcase)
 
     addTests = add_tests
 
